@@ -56,6 +56,16 @@ def collection_config_path(tmp_path):
     os.chdir(old_cwd)
 
 
+@pytest.fixture
+def other_config_path(tmp_path):
+    old_cwd = os.getcwd()
+    os.chdir(tmp_path)
+    d = tmp_path / 'changelogs'
+    d.mkdir()
+    yield d / 'config.yaml'
+    os.chdir(old_cwd)
+
+
 def test_detect_complete_fail(root):
     with pytest.raises(ChangelogError):
         PathsConfig.detect()
@@ -74,6 +84,8 @@ def test_detect_ansible_doc_binary(cwd_tmp_path):
     d.mkdir()
     (d / 'config.yaml').write_text('---')
     c = PathsConfig.detect()
+    assert c.is_other_project is False
+    assert c.is_collection is False
     assert c.ansible_doc_path == 'ansible-doc'
 
 
@@ -88,6 +100,27 @@ def test_detect_ansible_no_doc_binary(cwd_tmp_path):
     d.mkdir()
     (d / 'config.yaml').write_text('---')
     c = PathsConfig.detect()
+    assert c.is_other_project is False
+    assert c.is_collection is False
+    assert c.ansible_doc_path == 'ansible-doc'
+
+
+def test_detect_other(cwd_tmp_path):
+    d = cwd_tmp_path / 'lib'
+    d.mkdir()
+    d = d / 'ansible'
+    d.mkdir()
+    d = cwd_tmp_path / 'bin'
+    d.mkdir()
+    ansible_doc = d / 'ansible-doc'
+    ansible_doc.write_text('#!/usr/bin/python')
+    (cwd_tmp_path / 'galaxy.yml').write_text('')
+    d = cwd_tmp_path / 'changelogs'
+    d.mkdir()
+    (d / 'config.yaml').write_text('is_other_project: true')
+    c = PathsConfig.detect()
+    assert c.is_other_project is True
+    assert c.is_collection is False
     assert c.ansible_doc_path == 'ansible-doc'
 
 
@@ -110,6 +143,8 @@ def test_config_loading_bad_keep_fragments(ansible_config_path):
 def test_config_store_ansible(ansible_config_path):
     ansible_config_path.write_text('')
     paths = PathsConfig.detect()
+    assert paths.is_collection is False
+    assert paths.is_other_project is False
     collection_details = CollectionDetails(paths)
 
     config = ChangelogConfig.default(paths, collection_details)
@@ -137,6 +172,8 @@ def test_config_store_ansible(ansible_config_path):
 def test_config_store_collection(collection_config_path):
     collection_config_path.write_text('')
     paths = PathsConfig.detect()
+    assert paths.is_collection is True
+    assert paths.is_other_project is False
     collection_details = CollectionDetails(paths)
 
     config = ChangelogConfig.default(paths, collection_details)
@@ -173,6 +210,46 @@ def test_config_store_collection(collection_config_path):
     assert config.flatmap is False
 
 
+def test_config_store_other(other_config_path):
+    other_config_path.write_text('is_other_project: true')
+    paths = PathsConfig.detect()
+    assert paths.is_collection is False
+    assert paths.is_other_project is True
+    collection_details = CollectionDetails(paths)
+
+    config = ChangelogConfig.default(paths, collection_details)
+    assert config.flatmap is None
+
+    config.store()
+    config = ChangelogConfig.load(paths, collection_details)
+    assert config.flatmap is None
+    assert config.is_other_project is True
+
+    config.always_refresh = 'full'
+    config.store()
+    config = ChangelogConfig.load(paths, collection_details)
+    assert config.always_refresh == 'full'
+    assert config.is_other_project is True
+
+    config.always_refresh = True
+    config.store()
+    config = ChangelogConfig.load(paths, collection_details)
+    assert config.always_refresh == 'full'
+    assert config.is_other_project is True
+
+    config.always_refresh = 'none'
+    config.store()
+    config = ChangelogConfig.load(paths, collection_details)
+    assert config.always_refresh == 'none'
+    assert config.is_other_project is True
+
+    config.always_refresh = False
+    config.store()
+    config = ChangelogConfig.load(paths, collection_details)
+    assert config.always_refresh == 'none'
+    assert config.is_other_project is True
+
+
 def test_collection_details(tmp_path):
     paths = PathsConfig.force_ansible(str(tmp_path))
     details = CollectionDetails(paths)
